==> citrus-spring-4.0.2-sources.jar: org/citrusframework/model/config/core/DirectSyncEndpointModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.core;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <extension base="{http://www.citrusframework.org/schema/config}DirectEndpointAdapterType">
 *       <attribute name="polling-interval" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-correlator" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "direct-sync-endpoint")
public class DirectSyncEndpointModel
    extends DirectEndpointAdapterType
{

    @XmlAttribute(name = "polling-interval")
    protected String pollingInterval;
    @XmlAttribute(name = "message-correlator")
    protected String messageCorrelator;

    /**
     * Ruft den Wert der pollingInterval-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPollingInterval() {
        return pollingInterval;
    }

    /**
     * Legt den Wert der pollingInterval-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPollingInterval(String value) {
        this.pollingInterval = value;
    }

    /**
     * Ruft den Wert der messageCorrelator-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageCorrelator() {
        return messageCorrelator;
    }

    /**
     * Legt den Wert der messageCorrelator-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageCorrelator(String value) {
        this.messageCorrelator = value;
    }

}

==> citrus-spring-4.1.0-sources.jar: org/citrusframework/model/config/core/DirectSyncEndpointModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.core;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für anonymous complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <extension base="{http://www.citrusframework.org/schema/config}DirectEndpointAdapterType">
 *       <attribute name="polling-interval" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-correlator" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "direct-sync-endpoint")
public class DirectSyncEndpointModel
    extends DirectEndpointAdapterType
{

    @XmlAttribute(name = "polling-interval")
    protected String pollingInterval;
    @XmlAttribute(name = "message-correlator")
    protected String messageCorrelator;

    /**
     * Ruft den Wert der pollingInterval-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPollingInterval() {
        return pollingInterval;
    }

    /**
     * Legt den Wert der pollingInterval-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPollingInterval(String value) {
        this.pollingInterval = value;
    }

    /**
     * Ruft den Wert der messageCorrelator-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageCorrelator() {
        return messageCorrelator;
    }

    /**
     * Legt den Wert der messageCorrelator-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageCorrelator(String value) {
        this.messageCorrelator = value;
    }

}
